==> syncope-3.0.0-M0-source-release.zip: syncope-3.0.0-M0/client/am/console/src/main/java/org/apache/syncope/client/console/commons/AMConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.client.console.commons;

public final class AMConstants {

    public static final String PREF_GATEWAYROUTE_PAGINATOR_ROWS = "gatewayroute.paginator.rows";

    public static final String PREF_WACONFIG_PAGINATOR_ROWS = "waconfig.paginator.rows";

    public static final String PREF_WASESSION_PAGINATOR_ROWS = "wasession.paginator.rows";

    public static final String PREF_AUTHMODULE_PAGINATOR_ROWS = "authmodule.paginator.rows";

    public static final String PREF_CLIENTAPP_PAGINATOR_ROWS = "clientapp.paginator.rows";

    public static final String PREF_CLIENTAPP_PROPERTIES_PAGINATOR_ROWS = "clientapp.properties.paginator.rows";

    public static final String PREF_ACCESS_POLICY_CONF_ATTRS_PAGINATOR_ROWS = "accesspolicy.conf.attrs.paginator.rows";

    public static final String PREF_SAML2_IDP_ENTITY_PAGINATOR_ROWS = "saml2idpentity.properties.paginator.rows";

    public static final String PREF_SAML2_SP_ENTITY_PAGINATOR_ROWS = "saml2spentity.properties.paginator.rows";

    public static final String PREF_AUTHPROFILE_PAGINATOR_ROWS = "authprofile.paginator.rows";

    public static final String PREF_AUTHPROFILE_IMPERSONATED_PAGINATOR_ROWS = "authprofile.impersonated.paginator.rows";

    public static final String PREF_AUTHPROFILE_GOOGLEMFAAUTHTOKENS_PAGINATOR_ROWS =
            "authprofile.googlemfaauthtokens.paginator.rows";

    public static final String PREF_AUTHPROFILE_GOOGLEMFAAUTHACCOUNTS_PAGINATOR_ROWS =
            "authprofile.googlemfaauthaccounts.paginator.rows";

    public static final String PREF_AUTHPROFILE_U2FDEVICES_PAGINATOR_ROWS = "authprofile.u2fdevices.paginator.rows";

    public static final String PREF_AUTHPROFILE_WEBAUTHNDEVICECREDENTIALS_PAGINATOR_ROWS =
            "authprofile.webAuthnDeviceCredentials.paginator.rows";

    private AMConstants() {
        // private constructor for static utility class
    }
}

==> syncope-4.0.0-M0-source-release.zip: syncope-4.0.0-M0/client/am/console/src/main/java/org/apache/syncope/client/console/commons/AMConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.client.console.commons;

public final class AMConstants {

    public static final String PREF_GATEWAYROUTE_PAGINATOR_ROWS = "gatewayroute.paginator.rows";

    public static final String PREF_WACONFIG_PAGINATOR_ROWS = "waconfig.paginator.rows";

    public static final String PREF_WASESSION_PAGINATOR_ROWS = "wasession.paginator.rows";

    public static final String PREF_AUTHMODULE_PAGINATOR_ROWS = "authmodule.paginator.rows";

    public static final String PREF_CLIENTAPP_PAGINATOR_ROWS = "clientapp.paginator.rows";

    public static final String PREF_CLIENTAPP_PROPERTIES_PAGINATOR_ROWS = "clientapp.properties.paginator.rows";

    public static final String PREF_ACCESS_POLICY_CONF_ATTRS_PAGINATOR_ROWS = "accesspolicy.conf.attrs.paginator.rows";

    public static final String PREF_SAML2_IDP_ENTITY_PAGINATOR_ROWS = "saml2idpentity.properties.paginator.rows";

    public static final String PREF_SAML2_SP_ENTITY_PAGINATOR_ROWS = "saml2spentity.properties.paginator.rows";

    public static final String PREF_AUTHPROFILE_PAGINATOR_ROWS = "authprofile.paginator.rows";

    public static final String PREF_AUTHPROFILE_IMPERSONATED_PAGINATOR_ROWS = "authprofile.impersonated.paginator.rows";

    public static final String PREF_AUTHPROFILE_GOOGLEMFAAUTHTOKENS_PAGINATOR_ROWS =
            "authprofile.googlemfaauthtokens.paginator.rows";

    public static final String PREF_AUTHPROFILE_GOOGLEMFAAUTHACCOUNTS_PAGINATOR_ROWS =
            "authprofile.googlemfaauthaccounts.paginator.rows";

    public static final String PREF_AUTHPROFILE_MFA_TRUSTED_FDEVICES_PAGINATOR_ROWS =
            "authprofile.mfaTrustedDevices.paginator.rows";

    public static final String PREF_AUTHPROFILE_WEBAUTHNDEVICECREDENTIALS_PAGINATOR_ROWS =
            "authprofile.webAuthnDeviceCredentials.paginator.rows";

    private AMConstants() {
        // private constructor for static utility class
    }
}
